# Generated by Django 2.2.4 on 2019-08-21 21:22

import datetime
import django.core.validators
from django.db import migrations, models
from django.utils import timezone


class Migration(migrations.Migration):

    dependencies = [("geography", "0002_point_pointlabeloffset")]

    operations = [
        migrations.AddField(
            model_name="division",
            name="created",
            field=models.DateTimeField(
                default=timezone.utc.localize(
                    datetime.datetime(2019, 1, 1, 0, 0)
                ),
                editable=False,
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="division",
            name="updated",
            field=models.DateTimeField(
                default=timezone.utc.localize(
                    datetime.datetime(2019, 1, 1, 0, 0)
                ),
                editable=False,
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="divisionlevel",
            name="created",
            field=models.DateTimeField(
                default=timezone.utc.localize(
                    datetime.datetime(2019, 1, 1, 0, 0)
                ),
                editable=False,
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="divisionlevel",
            name="updated",
            field=models.DateTimeField(
                default=timezone.utc.localize(
                    datetime.datetime(2019, 1, 1, 0, 0)
                ),
                editable=False,
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="geometry",
            name="created",
            field=models.DateTimeField(
                default=timezone.utc.localize(
                    datetime.datetime(2019, 1, 1, 0, 0)
                ),
                editable=False,
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="geometry",
            name="data_summary",
            field=models.SlugField(
                blank=True,
                editable=False,
                help_text="A brief description (written as a slug) of what makes this data unique from other Geometry instances with the same 'division' and 'subdivision_level' values.",
                max_length=255,
                unique=True,
            ),
        ),
        migrations.AddField(
            model_name="geometry",
            name="uid",
            field=models.CharField(blank=True, editable=False, max_length=500),
        ),
        migrations.AddField(
            model_name="geometry",
            name="updated",
            field=models.DateTimeField(
                default=timezone.utc.localize(
                    datetime.datetime(2019, 1, 1, 0, 0)
                ),
                editable=False,
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="intersectrelationship",
            name="created",
            field=models.DateTimeField(
                default=timezone.utc.localize(
                    datetime.datetime(2019, 1, 1, 0, 0)
                ),
                editable=False,
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="intersectrelationship",
            name="updated",
            field=models.DateTimeField(
                default=timezone.utc.localize(
                    datetime.datetime(2019, 1, 1, 0, 0)
                ),
                editable=False,
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="point",
            name="created",
            field=models.DateTimeField(
                default=timezone.utc.localize(
                    datetime.datetime(2019, 1, 1, 0, 0)
                ),
                editable=False,
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="point",
            name="uid",
            field=models.CharField(blank=True, editable=False, max_length=500),
        ),
        migrations.AddField(
            model_name="point",
            name="updated",
            field=models.DateTimeField(
                default=timezone.utc.localize(
                    datetime.datetime(2019, 1, 1, 0, 0)
                ),
                editable=False,
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="pointlabeloffset",
            name="created",
            field=models.DateTimeField(
                default=timezone.utc.localize(
                    datetime.datetime(2019, 1, 1, 0, 0)
                ),
                editable=False,
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="pointlabeloffset",
            name="uid",
            field=models.CharField(blank=True, editable=False, max_length=500),
        ),
        migrations.AddField(
            model_name="pointlabeloffset",
            name="updated",
            field=models.DateTimeField(
                default=timezone.utc.localize(
                    datetime.datetime(2019, 1, 1, 0, 0)
                ),
                editable=False,
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="geometry",
            name="simplification",
            field=models.FloatField(
                help_text="Minimum quantile of planar triangle areas for simplfying topojson.",
                validators=[
                    django.core.validators.MinValueValidator(0.0),
                    django.core.validators.MaxValueValidator(1.0),
                ],
            ),
        ),
        migrations.AlterUniqueTogether(
            name="geometry",
            unique_together={
                ("division", "subdivision_level", "data_summary")
            },
        ),
        migrations.AlterUniqueTogether(
            name="point", unique_together={("geometry", "label", "lat", "lon")}
        ),
    ]
