# Generated by Django 2.2.4 on 2020-03-09 23:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('geography', '0003_auto_20190821_2122'),
    ]

    operations = [
        migrations.AlterField(
            model_name='divisionlevel',
            name='name',
            field=models.CharField(choices=[('country', 'Country'), ('state', 'State'), ('district', 'District'), ('county', 'County'), ('township', 'Township'), ('precinct', 'Precinct'), ('abroad', 'Voters abroad')], max_length=255, unique=True),
        ),
    ]
